@@ -168,3 +168,13 @@ class HtmlTableParser(HTMLParser):
         sorted_data.insert(0, data[0])
 
         return sorted_data
+
+
+def strip_html_tags(text):
+    """
+    Removes HTML tags from the given string.
+
+    :param str text: The string we want remove tags from.
+    """
+
+    return re.sub(r"<.*?>", "", text)
