@@ -186,7 +186,7 @@ class TipRanks(BaseAPI):
             json_data = data.json()
 
             # Checking if symbol was even found.
-            if json_data[0]["currency"] is None:
+            if 0 == len(json_data) or "currency" not in json_data[0]:
                 raise SymbolNotFound
 
             return {
@@ -198,7 +198,6 @@ class TipRanks(BaseAPI):
             }
 
         async def main():
-
             basic, additionals = await asyncio.gather(
                 download_basics(self.symbol), download_additionals(self.symbol)
             )
